@@ -1,15 +1,20 @@
 QR.mm = function(X, y, tau, beta, maxit, toler)
 {
 
-if(nargs()<5){
+if(missing(toler)){
 	toler = 1e-3
-	maxit = 200
+	
+}
+
+if(missing(maxit))
+{
+maxit = 200
 }
 
 n=dim(X)[1]
 x=cbind(rep(1,n),X)
 
-if(nargs()<4){
+if(missing(beta)){
 	beta=solve(t(x)%*%x,t(x)%*%y)
 }
 
