@@ -1,16 +1,20 @@
 cqr.lasso.cd = function(X,y,tau,lambda,beta,maxit,toler)
 {
 
-if(nargs()<6){
+if(missing(toler)){
 	toler = 1e-3
+	
+}
+
+if(missing(maxit)){
 	maxit = 200
 }
 
-if(nargs()<5){
+if(missing(beta)){
 	beta=solve(t(X)%*%X,t(X)%*%y)
 }
 
-if(nargs()<4){
+if(missing(lambda)){
 	lambda=1
 }
 
